##  Monitor Progress Using Metrics
To monitor progress, use the following metrics on the onboarding dashboard for enterprise architects. For additional information, see [Understanding Best-Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
Metrics for Organizations Metric | Explanation
---|---
Level 1 organization: Add a minimum of 15, but no more than 20, to the workspace. Level 2 organization: Add a minimum of 5, but no more than 10 for each level 1 organization. | Starting with 15-20 organizations at level 1 provides a robust foundation and comprehensive overview while keeping the maintenance effort manageable. You can add more organizations at any time if needed.
Add no more than 2 levels of organization hierarchy to the workspace. | Avoiding excessive granularity is important to balance effort and productivity.
Ensure that at least 80% of organizations have a description. | Clear, concise, and universally understood definitions of organizations are crucial for your organization and stakeholders. This clarity is key to facilitating effective analysis and generating insightful outcomes within SAP LeanIX.


